@@ -1,5 +1,4 @@
 loglik <- function(object, size = 2){
-	if(missing(size)) stop("sample size is not specified")
 	if(size <= 0) stop("size must be a positive integer")
 	if(size != ceiling(size)) stop("size must be an integer value")
 	p <- dim(object$S)[1]
@@ -14,8 +13,8 @@ loglik <- function(object, size = 2){
 					 }
 					 )
 	out <- Kh(object)
-    out <- unlist(lapply(out, function(x){determinant(x, logarithm = TRUE)$modulus[1]}))
+   out <- unlist(lapply(out, function(x) determinant(x, logarithm = TRUE)$modulus[1]))
 	k <- 0.5 * size
-	out <- k * (log(out) - p + rho * l1_th_e)
+	out <- k * (out - p + rho * l1_th_e)
 	out
 }
