@@ -1,6 +1,6 @@
 mask2Te <- function(mask){
 	e <- mask[upper.tri(mask, diag = FALSE)]
-	ge <- setdiff(unique(e), "zero")
+	ge <- setdiff(unique(e), ".")
 	ne <- length(ge)
 	Te_list <- vector(mode = "list", length = ne)
 	Te_ptr_list <- vector(mode = "list", length = ne)
@@ -21,4 +21,4 @@ mask2Te <- function(mask){
 	else nme <- as.character(ge)
 	out <- list(Te = Te, Te_scn = Te_scn, Te_ptr = Te_ptr, Te_ptr_scn = Te_ptr_scn, ne = ne, nme = nme)
 	out
-}
\ No newline at end of file
+}
